Documentation
¶
Overview ¶
Package wabbit provides an interface for AMQP client specification and a mock implementation of that interface.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Channel ¶
type Channel interface {
Ack(tag uint64, multiple bool) error
Nack(tag uint64, multiple bool, requeue bool) error
Reject(tag uint64, requeue bool) error
Confirm(noWait bool) error
NotifyPublish(confirm chan Confirmation) chan Confirmation
Cancel(consumer string, noWait bool) error
ExchangeDeclare(name, kind string, opt Option) error
ExchangeDeclarePassive(name, kind string, opt Option) error
QueueDeclare(name string, args Option) (Queue, error)
QueueDeclarePassive(name string, args Option) (Queue, error)
QueueDelete(name string, args Option) (int, error)
QueueBind(name, key, exchange string, opt Option) error
QueueUnbind(name, route, exchange string, args Option) error
Consume(queue, consumer string, opt Option) (<-chan Delivery, error)
Qos(prefetchCount, prefetchSize int, global bool) error
Close() error
NotifyClose(chan Error) chan Error
Publisher
}
Channel is an AMQP channel interface
type Confirmation ¶
Confirmation is an interface to confrimation messages
type Conn ¶
type Conn interface {
Channel() (Channel, error)
AutoRedial(errChan chan Error, done chan bool)
Close() error
NotifyClose(chan Error) chan Error
}
Conn is the amqp connection interface
type Delivery ¶
type Delivery interface {
Ack(multiple bool) error
Nack(multiple, request bool) error
Reject(requeue bool) error
Body() []byte
Headers() Option
DeliveryTag() uint64
ConsumerTag() string
CorrelationId() string
MessageId() string
ReplyTo() string
Redelivered() bool
}
Delivery is an interface to delivered messages
Directories
¶
| Path | Synopsis |
|---|---|
|
_examples
|
|
|
publisher
command
|
|
|
simple-consumer
command
This example declares a durable Exchange, an ephemeral (auto-delete) Queue, binds the Queue to the Exchange with a binding key, and consumes every message published to that Exchange with that routing key.
|
This example declares a durable Exchange, an ephemeral (auto-delete) Queue, binds the Queue to the Exchange with a binding key, and consumes every message published to that Exchange with that routing key. |
|
worker_queue
command
|
|
Click to show internal directories.
Click to hide internal directories.